<?php

/**
 * Mission Section
 *
 * @package Charity_Elite
 */

$wp_customize->add_section(
	'charity_elite_mission_section',
	array(
		'panel'    => 'charity_elite_front_page_options',
		'title'    => esc_html__( 'Mission Section', 'charity-elite' ),
		'priority' => 40,
	)
);

// Mission Section - Enable Section.
$wp_customize->add_setting(
	'charity_elite_enable_mission_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'charity_elite_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Charity_Elite_Toggle_Switch_Custom_Control(
		$wp_customize,
		'charity_elite_enable_mission_section',
		array(
			'label'    => esc_html__( 'Enable Mission Section', 'charity-elite' ),
			'section'  => 'charity_elite_mission_section',
			'settings' => 'charity_elite_enable_mission_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'charity_elite_enable_mission_section',
		array(
			'selector' => '#charity_elite_mission_section .section-link',
			'settings' => 'charity_elite_enable_mission_section',
		)
	);
}

// Mission Section - Section Subtitle.
$wp_customize->add_setting(
	'charity_elite_mission_subtitle',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'charity_elite_mission_subtitle',
	array(
		'label'           => esc_html__( 'Mission Subtitle', 'charity-elite' ),
		'section'         => 'charity_elite_mission_section',
		'settings'        => 'charity_elite_mission_subtitle',
		'type'            => 'text',
		'active_callback' => 'charity_elite_is_mission_section_enabled',
	)
);

// Mission Section - Content Type.
$wp_customize->add_setting(
	'charity_elite_mission_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'charity_elite_sanitize_select',
	)
);

$wp_customize->add_control(
	'charity_elite_mission_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'charity-elite' ),
		'section'         => 'charity_elite_mission_section',
		'settings'        => 'charity_elite_mission_content_type',
		'type'            => 'select',
		'active_callback' => 'charity_elite_is_mission_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'charity-elite' ),
			'post' => esc_html__( 'Post', 'charity-elite' ),
		),
	)
);

// Mission Section - Content Type Post.
$wp_customize->add_setting(
	'charity_elite_mission_content_post',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'charity_elite_mission_content_post',
	array(
		'section'         => 'charity_elite_mission_section',
		'settings'        => 'charity_elite_mission_content_post',
		'label'           => esc_html__( 'Select Post', 'charity-elite' ),
		'active_callback' => 'charity_elite_is_mission_section_and_content_type_post_enabled',
		'type'            => 'select',
		'choices'         => charity_elite_get_post_choices(),
	)
);

// Mission Section - Content Type Page.
$wp_customize->add_setting(
	'charity_elite_mission_content_page',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'charity_elite_mission_content_page',
	array(
		'label'           => esc_html__( 'Select Page', 'charity-elite' ),
		'section'         => 'charity_elite_mission_section',
		'settings'        => 'charity_elite_mission_content_page',
		'active_callback' => 'charity_elite_is_mission_section_and_content_type_page_enabled',
		'type'            => 'select',
		'choices'         => charity_elite_get_page_choices(),
	)
);

// Mission Section - Mission Points.
$wp_customize->add_setting(
	'charity_elite_mission_points',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	new Charity_Elite_Multi_Input_Custom_control(
		$wp_customize,
		'charity_elite_mission_points',
		array(
			'label'           => esc_html__( 'Mission Points', 'charity-elite' ),
			'section'         => 'charity_elite_mission_section',
			'active_callback' => 'charity_elite_is_mission_section_enabled',
			'settings'        => 'charity_elite_mission_points',
		)
	)
);

// Mission Section - Button Label.
$wp_customize->add_setting(
	'charity_elite_mission_button_label',
	array(
		'default'           => __( 'Read More', 'charity-elite' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'charity_elite_mission_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'charity-elite' ),
		'section'         => 'charity_elite_mission_section',
		'settings'        => 'charity_elite_mission_button_label',
		'type'            => 'text',
		'active_callback' => 'charity_elite_is_mission_section_enabled',
	)
);
