<?php

/**
 * Service Section
 *
 * @package Charity_Elite
 */

$wp_customize->add_section(
	'charity_elite_service_section',
	array(
		'panel'    => 'charity_elite_front_page_options',
		'title'    => esc_html__( 'Service Section', 'charity-elite' ),
		'priority' => 60,
	)
);

// Service Section - Enable Section.
$wp_customize->add_setting(
	'charity_elite_enable_service_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'charity_elite_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Charity_Elite_Toggle_Switch_Custom_Control(
		$wp_customize,
		'charity_elite_enable_service_section',
		array(
			'label'    => esc_html__( 'Enable Service Section', 'charity-elite' ),
			'section'  => 'charity_elite_service_section',
			'settings' => 'charity_elite_enable_service_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'charity_elite_enable_service_section',
		array(
			'selector' => '#charity_elite_service_section .section-link',
			'settings' => 'charity_elite_enable_service_section',
		)
	);
}

// Service Section - Section Title.
$wp_customize->add_setting(
	'charity_elite_service_title',
	array(
		'default'           => __( 'What We Do For You', 'charity-elite' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'charity_elite_service_title',
	array(
		'label'           => esc_html__( 'Section Title', 'charity-elite' ),
		'section'         => 'charity_elite_service_section',
		'settings'        => 'charity_elite_service_title',
		'type'            => 'text',
		'active_callback' => 'charity_elite_is_service_section_enabled',
	)
);

// Service Section - Section Subtitle.
$wp_customize->add_setting(
	'charity_elite_service_subtitle',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'charity_elite_service_subtitle',
	array(
		'label'           => esc_html__( 'Section Subtitle', 'charity-elite' ),
		'section'         => 'charity_elite_service_section',
		'settings'        => 'charity_elite_service_subtitle',
		'type'            => 'text',
		'active_callback' => 'charity_elite_is_service_section_enabled',
	)
);

// Service Section - Button Label.
$wp_customize->add_setting(
	'charity_elite_service_button_label',
	array(
		'default'           => __( 'Read More', 'charity-elite' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'charity_elite_service_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'charity-elite' ),
		'section'         => 'charity_elite_service_section',
		'settings'        => 'charity_elite_service_button_label',
		'type'            => 'text',
		'active_callback' => 'charity_elite_is_service_section_enabled',
	)
);

// Service Section - Content Type.
$wp_customize->add_setting(
	'charity_elite_service_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'charity_elite_sanitize_select',
	)
);

$wp_customize->add_control(
	'charity_elite_service_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'charity-elite' ),
		'section'         => 'charity_elite_service_section',
		'settings'        => 'charity_elite_service_content_type',
		'type'            => 'select',
		'active_callback' => 'charity_elite_is_service_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'charity-elite' ),
			'post' => esc_html__( 'Post', 'charity-elite' ),
		),
	)
);

for ( $i = 1; $i <= 3; $i++ ) {

	// Service Section - Services Icons.
	$wp_customize->add_setting(
		'charity_elite_service_icon_' . $i,
		array(
			'sanitize_callback' => 'charity_elite_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'charity_elite_service_icon_' . $i,
			array(
				'label'           => sprintf( esc_html__( 'Service Icon %d', 'charity-elite' ), $i ),
				'section'         => 'charity_elite_service_section',
				'settings'        => 'charity_elite_service_icon_' . $i,
				'active_callback' => 'charity_elite_is_service_section_enabled',
			)
		)
	);

	// Service Section - Select Post.
	$wp_customize->add_setting(
		'charity_elite_service_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'charity_elite_service_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'charity-elite' ) . $i,
			'section'         => 'charity_elite_service_section',
			'settings'        => 'charity_elite_service_content_post_' . $i,
			'active_callback' => 'charity_elite_is_service_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => charity_elite_get_post_choices(),
		)
	);

	// Service Section - Select Page.
	$wp_customize->add_setting(
		'charity_elite_service_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'charity_elite_service_content_page_' . $i,
		array(
			'label'           => esc_html__( 'Select Page ', 'charity-elite' ) . $i,
			'section'         => 'charity_elite_service_section',
			'settings'        => 'charity_elite_service_content_page_' . $i,
			'active_callback' => 'charity_elite_is_service_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => charity_elite_get_page_choices(),
		)
	);
}
